exercise_progress

Function exercise_progress 

async fn exercise_progress(
    conn: &mut PgConnection,
    user_id: Uuid,
    exercise: &Exercise,
    course_id: Uuid,
    state: Option<&UserExerciseState>,
) -> ModelResult<ExerciseProgress>
The user’s progress on an exercise of the given course, with state their exercise state (absent when they have never touched the exercise). Reads the try counts only when they can decide the standing.