get_course_exercises

Function get_course_exercises 

async fn get_course_exercises(
    pool: Data<PgPool>,
    user: UserFromOAuthToken,
    course: Path<Uuid>,
    file_store: Data<dyn FileStore>,
    app_conf: Data<ApplicationConfiguration>,
    _client: SupportedClient,
) -> ControllerResult<Json<Vec<ExerciseSlide>>>
  • GET /api/v0/exercise-services/client/courses/:id/exercises
  • Returns the user’s exercise slides for the given course.
  • Does not return anything for chapters which are not open yet.
  • Selects slides for exercises with no slide selected yet.
  • Only returns slides which have tasks whose exercise service can serve this client.