has_received_full_points

Function has_received_full_points 

fn has_received_full_points(
    score_given: Option<f32>,
    score_maximum: i32,
) -> bool
Full points as the course material judges them, tolerating float rounding. None (never graded) is not full points even when the exercise is worth 0.