submit_exercise

Function submit_exercise 

async fn submit_exercise(
    pool: Data<PgPool>,
    file_store: Data<dyn FileStore>,
    jwt_key: Data<JwtKey>,
    exercise_id: Path<Uuid>,
    submission: Json<ExerciseSlideSubmission>,
    user: UserFromOAuthToken,
    app_conf: Data<ApplicationConfiguration>,
    _client: SupportedClient,
) -> ControllerResult<Json<ExerciseTaskSubmissionResult>>
  • POST /api/v0/exercise-services/client/exercises/:id/submit
  • Accepts an exercise submission from the user. A file answer names files previously stored
  • through this exercise’s files endpoint, in the order they are to be graded; those files are the
  • answer. An answer that names no files is a JSON answer, carried in data_json.