Function download_submission
Source async fn download_submission(
pool: Data<PgPool>,
file_store: Data<dyn FileStore>,
submission_id: Path<Uuid>,
user: UserFromOAuthToken,
app_conf: Data<ApplicationConfiguration>,
_client: SupportedClient,
) -> ControllerResult<Json<SubmissionFiles>>
- GET /api/v0/exercise-services/client/submissions/:id/download
- Resolves an exercise-slide submission (by the id returned from the submissions list, or by
- a submit’s
slide_submission_id) to the files it was made from, so the client can restore
- an old submission.